package com.tongyi.videochatdemo;

import android.Manifest.permission;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.webkit.JavascriptInterface;
import android.webkit.PermissionRequest;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceRequest;
import android.webkit.WebResourceResponse;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.content.ContextCompat;

import com.tongyi.video_chat_sdk.Constant;
import com.tongyi.video_chat_sdk.Constant.TYVoiceChatMode;
import com.tongyi.video_chat_sdk.data.request.TYRTCAuthParams;
import com.tongyi.video_chat_sdk.data.request.TYRequestConfig;
import com.tongyi.video_chat_sdk.util.DeviceUtil;

import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import com.tongyi.videochatdemo.R;

/**
 * @author haojiahe
 * @date 2024/11/26
 * description:
 */
public class NativeChatConfigActivity extends AppCompatActivity {
    private static final String TAG = NativeChatConfigActivity.class.getSimpleName();
    private static final int PERMISSION_REQUEST_CODE = 100;

    /**
     * 是否使用RTC内置的AEC
     */
    private CheckBox cbUseRtcAec;
    private EditText etModelId;
    private EditText etAvatarId;
    private EditText etVoice;
    private EditText etAppkey;
    private EditText etCharacterId;
    private Button btStart;
    private RadioGroup rbChatType;
    private String mMode = "tap2talk";
    private String mModelId;
    private String mAvatarId;
    private String mVoice;
    private String mAppkey;
    private String mCharacterId;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        DeviceUtil.setStatusBarColor(this);
        setContentView(R.layout.activity_native_chat_config);
        initView();
        checkPermission();
    }

    private void initView() {
        cbUseRtcAec = findViewById(R.id.cb_use_rtc_aec);
        etModelId = findViewById(R.id.etModelId);
        etAvatarId = findViewById(R.id.etAvatarId);
        etVoice = findViewById(R.id.etVoice);
        etAppkey = findViewById(R.id.etAppkey);
        etCharacterId = findViewById(R.id.etCharacterId);
        btStart = findViewById(R.id.btStartChat);

        btStart.setOnClickListener(view -> verifyInput());

        rbChatType = findViewById(R.id.rbChatType);
        rbChatType.setOnCheckedChangeListener((group, checkedId) -> {
            // 根据 checkedId 获取被选中的 RadioButton
            if (checkedId == R.id.rb_push2talk) {
                mMode = TYVoiceChatMode.PUSH2TALK;
            } else if (checkedId == R.id.rb_tap2talk) {
                mMode = TYVoiceChatMode.TAP2TALK;
            } else if (checkedId == R.id.rb_duplex) {
                mMode = TYVoiceChatMode.DUPLEX;
            }
        });
    }

    private void verifyInput() {
        mModelId = etModelId.getText().toString().trim();
        if (mModelId.isEmpty()) {
            mModelId = "xingchen-plus-v2";
        }
        mAvatarId = etAvatarId.getText().toString().trim();
        if (mAvatarId.isEmpty()) {
            Toast.makeText(this, "请输入AvatarId", Toast.LENGTH_SHORT).show();
            return;
        }
        mVoice = etVoice.getText().toString().trim();
        if (mVoice.isEmpty()) {
            Toast.makeText(this, "请输入VoiceId", Toast.LENGTH_SHORT).show();
            return;
        }
        mAppkey = etAppkey.getText().toString().trim();
        if (mAppkey.isEmpty()) {
            Toast.makeText(NativeChatConfigActivity.this, "请输入Appkey", Toast.LENGTH_SHORT).show();
            return;
        }
        mCharacterId = etCharacterId.getText().toString().trim();
        if (mCharacterId.isEmpty()) {
            Toast.makeText(NativeChatConfigActivity.this, "请输入mCharacterId", Toast.LENGTH_SHORT).show();
            return;
        }
        String payload = "{" +
                "\"model_id\":\"" + mModelId + "\"," +
                "\"voice\":\"" + mVoice + "\"," +
                "\"avatar_id\":\"" + mAvatarId + "\"," +
                "\"type\":\"Avatar\"," +
                "\"mode\":\"" + mMode + "\"," +
                "\"Appkey\":\"" + mAppkey + "\"," +
                "\"character_id\":\"" + mCharacterId + "\"," +
                "\"prompt\":\"\"}";
        Log.d(TAG, "verifyInput: 传的payload值：" + payload);
        startRTC(payload);
    }

    /**
     * @param payload 请求配置参数，值参考如下
     *                {"model_id":"qwen-plus","voice":"longxiaochun","avatar_id":"pre-avatar_sariebott_cpu-2175",
     *                "prompt":""}
     */
    public void startRTC(String payload) {
        genLaunchParams(payload);
        if (NativeChatConfigActivity.this.checkPermission()) {
            launchVideoChat();
        }
    }

    private TYRTCAuthParams authParams;
    private TYRequestConfig requestConfig;

    /**
     * 拉起VideoChat页
     *
     * @return true or false
     */
    private boolean launchVideoChat() {
        if (null == authParams || null == requestConfig) {
            Log.e(TAG, "launch failed without authParams or requestConfig");
            return false;
        }
        boolean startRe = VideoChatActivity.launchVideoChat(NativeChatConfigActivity.this, authParams, requestConfig);
        Log.d(TAG, "startRTC called payload:" + authParams + ";requestConfig:" + requestConfig
                + ";startResult:" + startRe);
        return startRe;
    }

    private boolean checkPermission() {
        if (ContextCompat.checkSelfPermission(this, permission.RECORD_AUDIO) != PackageManager.PERMISSION_GRANTED) {
            requestPermissions(new String[]{permission.RECORD_AUDIO}, PERMISSION_REQUEST_CODE);
            return false;
        }
        return true;
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions,
                                           @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode == PERMISSION_REQUEST_CODE && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            launchVideoChat();
        }
    }

    /**
     * 生成请求参数
     *
     * @param payload 前端传过来的，用户输入的参数表
     */
    private void genLaunchParams(String payload) {
        try {
            //{"model_id":"qwen-plus","voice":"longxiaochun","avatar_id":"pre-avatar_sariebott_cpu-2175",
            // "mode","tap2talk"}
            JSONObject payloadObject = new JSONObject(payload);
            String apiKey = payloadObject.getString("Appkey");

            authParams = new TYRTCAuthParams();
            // 这三个是必填项
            authParams.setVoiceId(payloadObject.getString("voice"));
            authParams.setAvatarId(payloadObject.getString("avatar_id"));
            authParams.setMode(payloadObject.getString("mode"));

            // characterId填入从星尘平台获取的值
            String characterId = "ed187c39234645bf8da9b9d3003ec936";
            if (payloadObject.has("character_id")) {
                characterId = payloadObject.getString("character_id");
            }

            UUID uuid = UUID.randomUUID();
            String userId = uuid.toString().replace("-", "");
            authParams.setCharacterId(characterId);
            authParams.setAppId("");
            authParams.setUserId(userId);
            authParams.setContent("");
            authParams.setExtras(null);
            authParams.setUseRtcAec(cbUseRtcAec.isChecked());

            // RequestConfig，用户在请求鉴权接口时，开放一些配置权限
            requestConfig = new TYRequestConfig();
            requestConfig.setUrl(Constant.VOICE_INITIALIZED_URL);
            Map<String, String> externalHeaders = new HashMap<>(16);
            externalHeaders.put("x-fag-servicename", "aca-videochat-init");
            externalHeaders.put("x-fag-appcode", "aca");
            externalHeaders.put("Authorization", "Bearer " + apiKey);
            requestConfig.setHeaders(externalHeaders);
        } catch (Exception ex) {
            ex.printStackTrace();
            authParams = null;
            requestConfig = null;
        }
    }
}
